<?php

namespace Superrobota\Mediaprovider\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Mediaprovider\Models\Mediaprovider;

class MediaproviderPolicy
{

    /**
     * Determine if the given user can view the mediaprovider.
     *
     * @param UserPolicy $user
     * @param Mediaprovider $mediaprovider
     *
     * @return bool
     */
    public function view(UserPolicy $user, Mediaprovider $mediaprovider)
    {
        if ($user->canDo('mediaprovider.mediaprovider.view') && $user->isAdmin()) {
            return true;
        }

        return $mediaprovider->user_id == user_id() && $mediaprovider->user_type == user_type();
    }

    /**
     * Determine if the given user can create a mediaprovider.
     *
     * @param UserPolicy $user
     * @param Mediaprovider $mediaprovider
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('mediaprovider.mediaprovider.create');
    }

    /**
     * Determine if the given user can update the given mediaprovider.
     *
     * @param UserPolicy $user
     * @param Mediaprovider $mediaprovider
     *
     * @return bool
     */
    public function update(UserPolicy $user, Mediaprovider $mediaprovider)
    {
        if ($user->canDo('mediaprovider.mediaprovider.edit') && $user->isAdmin()) {
            return true;
        }

        return $mediaprovider->user_id == user_id() && $mediaprovider->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given mediaprovider.
     *
     * @param UserPolicy $user
     * @param Mediaprovider $mediaprovider
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Mediaprovider $mediaprovider)
    {
        return $mediaprovider->user_id == user_id() && $mediaprovider->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given mediaprovider.
     *
     * @param UserPolicy $user
     * @param Mediaprovider $mediaprovider
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Mediaprovider $mediaprovider)
    {
        if ($user->canDo('mediaprovider.mediaprovider.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given mediaprovider.
     *
     * @param UserPolicy $user
     * @param Mediaprovider $mediaprovider
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Mediaprovider $mediaprovider)
    {
        if ($user->canDo('mediaprovider.mediaprovider.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
